pydiffx - Python Reader/Writer for DiffX Files
==============================================

pydiffx is a Python implementation of the `DiffX specification
<https://diffx.org/spec/index.html>`_.

DiffX is a proposed specification for a structured version of Unified Diffs
that contains metadata, standardized parsing, multi-commit diffs, and binary
diffs, in a format compatible with existing diff parsers. `Learn more
<https://diffx.org>`_.

This module is a reference implementation designed to make it easy to read and
write DiffX files in any Python application.


Compatibility
=============

* Python 2.7
* Python 3.6
* Python 3.7
* Python 3.8
* Python 3.9


Installation
============

pydiffx can be installed using ``pip``::

   pip install -U pydiffx


Using pydiffx
=============

See the `documentation <https://diffx.org/pydiffx/>`_ for tutorials and
code references.
